#include <pthread.h>
#include <gtk/gtk.h>
#include "specimen.h"
#include "gui/gui.h"
#include "midi.h"
#include "driver.h"
#include "lfo.h"
#include "patch.h"
#include "mixer.h"

#ifdef HAVE_LADCCA
# include <ladcca/ladcca.h>
# include "leash.h"
#endif

int main (int argc, char *argv[])
{
#ifdef HAVE_LADCCA
     cca_args_t *cca_args;

     cca_args = cca_extract_args (&argc, &argv);
     leash_init (cca_args);
#endif

     gtk_init (&argc, &argv);

     /* constructors */
     driver_init ( );
     lfo_init    ( );
     gui_init    ( );
     patch_init  ( );
     mixer_init  ( );

     /* start */
     midi_start   ( );
     driver_start (0);

#ifdef HAVE_LADCCA
     /* Start LADCCA loop */
     g_timeout_add (10000, (GtkFunction) leash_idle, NULL);
#endif

     gtk_main ( );

     /* stop */
     midi_stop   ( );
     driver_stop ( );

     /* destructors */
     patch_shutdown ( );
     mixer_shutdown ( );

     debug ("Goodbye.\n");
     return 0;
}
